import 'package:dotup_flutter_simulator/dotup_flutter_simulator.dart';
import 'package:flutter/material.dart';

import 'dotup_flutter_mockups_app.dart';
import 'mockup_descriptor.dart';
import 'settings/settings_controller.dart';

const bool debugEnableDeviceSimulator = true;

Map<int, Color> toMaterialColor(Color color) {
  return {
    50: Color.fromRGBO(color.red, color.green, color.blue, .1),
    100: Color.fromRGBO(color.red, color.green, color.blue, .2),
    200: Color.fromRGBO(color.red, color.green, color.blue, .3),
    300: Color.fromRGBO(color.red, color.green, color.blue, .4),
    400: Color.fromRGBO(color.red, color.green, color.blue, .5),
    500: Color.fromRGBO(color.red, color.green, color.blue, .6),
    600: Color.fromRGBO(color.red, color.green, color.blue, .7),
    700: Color.fromRGBO(color.red, color.green, color.blue, .8),
    800: Color.fromRGBO(color.red, color.green, color.blue, .9),
    900: Color.fromRGBO(color.red, color.green, color.blue, 1),
  };
}
// void main() => runApp(MyApp());

class MockupApp extends StatefulWidget {
  MockupApp({
    Key? key,
    required this.settingsController,
    required this.mockupDescriptor,
    required this.enabled,
    this.showColorSelector = true,
    // this.theme,
    // this.darkTheme,
  }) : super(key: key);

  SettingsController settingsController;
  final MockupDescriptor mockupDescriptor;
  final bool enabled;
  final bool showColorSelector;
  // final ThemeData? theme;
  // final ThemeData? darkTheme;

  @override
  State<MockupApp> createState() => _MockupAppState();
}

class _MockupAppState extends State<MockupApp> {
  late ThemeMode themeMode;
  late Brightness brightness;
  // late ThemeData theme;
  // late ThemeData darkTheme;

  @override
  void initState() {
    super.initState();
    themeMode = ThemeMode.dark;
    brightness = Brightness.dark;
    // theme = widget.theme ?? ThemeData.light();
    // darkTheme = widget.darkTheme ?? ThemeData.dark();
  }

  @override
  Widget build(BuildContext context) {
    return MaterialApp(
      // key: ValueKey(brightness),
      debugShowCheckedModeBanner: false,
      title: 'dotup Flutter prototyping',
      scrollBehavior: DesktopScrollBehavior(),
      themeMode: themeMode,
      // theme: theme,
      // darkTheme: darkTheme,
      home: DeviceSimulator(
        initialDeviceIndex: 3,
        initialPlatform: TargetPlatform.android,
        orientation: Orientation.portrait,
        brightness: brightness,
        enable: widget.enabled,
        androidShowNavigationBar: false,
        showColorSelector: widget.showColorSelector,
        onColorChanged: (value) {
          final theme =
              ThemeData(brightness: Brightness.dark, primarySwatch: MaterialColor(value!.color!.value, toMaterialColor(value.color!)));
          // darkTheme =
          //     ThemeData(brightness: Brightness.light, primarySwatch: MaterialColor(value.color!.value, toMaterialColor(value.color!)));
          final darkTheme = ThemeData(brightness: Brightness.dark, primarySwatch: Colors.red);
          widget.settingsController.updateTheme(theme: theme, darkTheme: darkTheme);
          // setState(() {
          //   theme =
          //       ThemeData(brightness: Brightness.dark, primarySwatch: MaterialColor(value!.color!.value, toMaterialColor(value.color!)));
          //   darkTheme =
          //       ThemeData(brightness: Brightness.light, primarySwatch: MaterialColor(value.color!.value, toMaterialColor(value.color!)));
          //   darkTheme = ThemeData(brightness: Brightness.dark, primarySwatch: Colors.red);
          // });
        },
        onBrightnessChanged: (value) {
          setState(() {
            brightness = value;
            themeMode = value == Brightness.dark ? ThemeMode.dark : ThemeMode.light;
            widget.settingsController.updateThemeMode(themeMode);
          });
        },
        builder: (context) {
          return DotupFlutterMockupsApp(
            settingsController: widget.settingsController,
            mockupDescriptor: widget.mockupDescriptor,
          );
        },
      ),
    );
  }
}
